/*============================================================================

The Medical Imaging Interaction Toolkit (MITK)

Copyright (c) German Cancer Research Center (DKFZ)
All rights reserved.

Use of this source code is governed by a 3-clause BSD license that can be
found in the LICENSE file.

============================================================================*/

#include "berryRegistryConstants.h"

namespace berry {

const QString RegistryConstants::RUNTIME_NAME = "org.blueberry.core.runtime";

const QString RegistryConstants::PROP_NO_REGISTRY_FLUSHING = "BlueBerry.noRegistryFlushing";
const QString RegistryConstants::PROP_NO_LAZY_REGISTRY_CACHE_LOADING = "BlueBerry.noLazyRegistryCacheLoading";
const QString RegistryConstants::PROP_CHECK_CONFIG = "osgi.checkConfiguration";
const QString RegistryConstants::PROP_NO_REGISTRY_CACHE = "BlueBerry.noRegistryCache";
const QString RegistryConstants::PROP_DEFAULT_REGISTRY = "BlueBerry.createRegistry";
const QString RegistryConstants::PROP_REGISTRY_nullptr_USER_TOKEN = "BlueBerry.registry.nulltoken";
const QString RegistryConstants::PROP_REGISTRY_MULTI_LANGUAGE = "BlueBerry.registry.MultiLanguage";

const int RegistryConstants::PLUGIN_ERROR = 1;

}
